#!/usr/bin/env python

"""
Set a quota limit for a user group.

Copyright (C) 2016 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from os.path import abspath, split
import sys

# Find the modules.

try:
    import imiptools
except ImportError:
    parent = abspath(split(split(__file__)[0])[0])
    if split(parent)[1] == "imip-agent":
        sys.path.append(parent)

from imiptools import config
from imiptools.stores import get_journal

# Main program.

if __name__ == "__main__":

    # Interpret the command line arguments.

    args = []
    store_type = []
    journal_dir = []

    # Collect quota details first, switching to other arguments when encountering
    # switches.

    l = args

    for arg in sys.argv[1:]:
        if arg == "-T":
            l = store_type
        elif arg == "-j":
            l = journal_dir
        else:
            l.append(arg)

    try:
        quota, group, limit = args
    except ValueError:
        print >>sys.stderr, """\
Usage: %s <quota> <group> <limit> [ <options> ]

General options:

-j  Indicates the journal directory location
-T  Indicates the store type (the configured value if omitted)
""" % split(sys.argv[0])[1]
        sys.exit(1)

    # Override defaults if indicated.

    getvalue = lambda value, default=None: value and value[0] or default

    store_type = getvalue(store_type, config.STORE_TYPE)
    journal_dir = getvalue(journal_dir)

    # Obtain store-related objects.

    journal = get_journal(store_type, journal_dir)
    journal.set_limit(quota, group, limit)

# vim: tabstop=4 expandtab shiftwidth=4
