#!/usr/bin/env python

"""
Update the scheduling modules import manifest.

Copyright (C) 2016 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from glob import glob
from os.path import join, split, splitext
import imiptools.handlers

reserved = ["__init__.py", "manifest.py"]

# The main program generating a new version of the manifest module.

if __name__ == "__main__":
    dirname = join(split(imiptools.handlers.__file__)[0], "scheduling")

    # Get all Python files in the scheduling directory, filtering out the
    # reserved files that do not provide scheduling functions.

    filenames = []
    for filename in glob(join(dirname, "*.py")):
        filename = split(filename)[-1]
        if filename not in reserved:
            filenames.append(filename)

    # Open the manifest module and write code to import and combine the
    # functions from each module.

    f = open(join(dirname, "manifest.py"), "w")
    try:
        print >>f, """\
confirmation_functions = {}
locking_functions = {}
retraction_functions = {}
scheduling_functions = {}
unlocking_functions = {}
"""

        for filename in filenames:
            module = splitext(filename)[0]

            print >>f, """\
from imiptools.handlers.scheduling.%s import (
    confirmation_functions as c,
    locking_functions as l,
    retraction_functions as r,
    scheduling_functions as s,
    unlocking_functions as u)

confirmation_functions.update(c)
locking_functions.update(l)
retraction_functions.update(r)
scheduling_functions.update(s)
unlocking_functions.update(u)
""" % module

    finally:
        f.close()

# vim: tabstop=4 expandtab shiftwidth=4
